==> nmrium-0.50.1.tgz: package/lib/component/reducer/actions/IntegralsActions.js <==
import { v4 } from '@lukeed/uuid';
import { original } from 'immer';
import { xyIntegration } from 'ml-spectra-processing';
import { updateIntegralsRelativeValues, changeIntegralsRelative, getShiftX, } from '../../../data/data1d/Spectrum1D';
import { initSumOptions, setSumOptions, } from '../../../data/data1d/Spectrum1D/SumManager';
import { getActiveSpectrum } from '../helper/getActiveSpectrum';
import getRange from '../helper/getRange';
import { getSpectrum } from '../helper/getSpectrum';
import { setIntegralsViewProperty } from '../helper/setIntegralsViewProperty';
function handleChangeIntegralSum(draft, action) {
    const { options } = action.payload;
    const { data, view: { spectra: { activeTab: nucleus }, }, } = draft;
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum?.id) {
        const { index } = activeSpectrum;
        const datum = data[index];
        setSumOptions(datum.integrals, { options, nucleus });
        updateIntegralsRelativeValues(datum, true);
    }
}
function initiateIntergalSumOptions(datum, options) {
    const { molecules, nucleus } = options;
    datum.integrals.options = initSumOptions(datum.integrals.options, {
        molecules,
        nucleus,
    });
}
function addIntegral(datum, options) {
    const { from, to } = options;
    const { x, re } = datum.data;
    const shiftX = getShiftX(datum);
    const integration = xyIntegration({ x, y: re }, { from, to, reverse: true });
    const integral = {
        id: v4(),
        originalFrom: from - shiftX,
        originalTo: to - shiftX,
        from,
        to,
        integral: integration,
        absolute: integration,
        kind: 'signal',
    };
    datum.integrals.values.push(integral);
}
function handleAddIntegral(draft, action) {
    const { startX, endX } = action.payload;
    const { data, molecules, view: { spectra: { activeTab: nucleus }, }, } = draft;
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum?.id) {
        const [from, to] = getRange(draft, { startX, endX });
        const datum = data[activeSpectrum.index];
        addIntegral(datum, { from, to });
        initiateIntergalSumOptions(datum, { molecules, nucleus });
        updateIntegralsRelativeValues(datum);
    }
}
function handleDeleteIntegral(draft, action) {
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum) {
        const state = original(draft);
        const { index } = activeSpectrum;
        const { id: integralID } = action?.payload || {};
        const datum = draft.data[index];
        if (!integralID) {
            datum.integrals.values = [];
        }
        else {
            const peakIndex = state.data[index].integrals.values.findIndex((p) => p.id === integralID);
            datum.integrals.values.splice(peakIndex, 1);
            updateIntegralsRelativeValues(datum);
        }
    }
}
function handleChangeIntegral(draft, action) {
    const activeSpectrum = getActiveSpectrum(draft);
    const state = original(draft);
    const { integral } = action.payload;
    if (activeSpectrum?.id) {
        const { index } = activeSpectrum;
        const originalDatum = state.data[index];
        const datum = draft.data[index];
        const { x, re } = originalDatum.data;
        const integralIndex = originalDatum.integrals.values.findIndex((i) => i.id === integral.id);
        if (integralIndex !== -1) {
            datum.integrals.values[integralIndex] = {
                ...integral,
                originalFrom: integral.from,
                originalTo: integral.to,
                absolute: xyIntegration({ x, y: re }, { from: integral.from, to: integral.to, reverse: true }),
            };
            updateIntegralsRelativeValues(datum);
        }
    }
}
function handleChangeIntegralsRelativeValue(draft, action) {
    const activeSpectrum = getActiveSpectrum(draft);
    const { id, value } = action.payload;
    if (activeSpectrum?.id) {
        const { index } = activeSpectrum;
        changeIntegralsRelative(draft.data[index], { id, value });
    }
}
function handleChangeIntegralsSumFlag(draft) {
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum) {
        const { index } = activeSpectrum;
        const integralOptions = draft.data[index].integrals.options;
        integralOptions.isSumConstant = !integralOptions.isSumConstant;
    }
}
function handleCutIntegral(draft, action) {
    const { cutValue } = action.payload;
    const spectrum = getSpectrum(draft);
    const integrals = spectrum.integrals.values;
    for (let i = 0; i < integrals.length; i++) {
        const { to, from } = integrals[i];
        if (cutValue > from && cutValue < to) {
            integrals.splice(i, 1);
            addIntegral(spectrum, { from, to: cutValue });
            addIntegral(spectrum, { from: cutValue, to });
        }
    }
    updateIntegralsRelativeValues(spectrum);
}
function toggleIntegralsViewProperty(draft, key) {
    setIntegralsViewProperty(draft, key, (flag) => !flag);
}
//action
function handleToggleIntegralsViewProperty(draft, action) {
    const { key } = action.payload;
    toggleIntegralsViewProperty(draft, key);
}
export { handleCutIntegral, handleChangeIntegralSum, handleAddIntegral, handleDeleteIntegral, handleChangeIntegral, handleChangeIntegralsRelativeValue, handleChangeIntegralsSumFlag, handleToggleIntegralsViewProperty, };

==> nmrium-0.53.0.tgz: package/lib/component/reducer/actions/IntegralsActions.js <==
import { v4 } from '@lukeed/uuid';
import { original } from 'immer';
import { xyIntegration } from 'ml-spectra-processing';
import { updateIntegralsRelativeValues, changeIntegralsRelative, getShiftX, } from '../../../data/data1d/Spectrum1D';
import { initSumOptions, setSumOptions, } from '../../../data/data1d/Spectrum1D/SumManager';
import { getActiveSpectrum } from '../helper/getActiveSpectrum';
import getRange from '../helper/getRange';
import { getSpectrum } from '../helper/getSpectrum';
import { setIntegralsViewProperty } from '../helper/setIntegralsViewProperty';
function handleChangeIntegralSum(draft, action) {
    const { options } = action.payload;
    const { data, view: { spectra: { activeTab: nucleus }, }, } = draft;
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum?.id) {
        const { index } = activeSpectrum;
        const datum = data[index];
        setSumOptions(datum.integrals, { options, nucleus });
        updateIntegralsRelativeValues(datum, true);
    }
}
function initiateIntergalSumOptions(datum, options) {
    const { molecules, nucleus } = options;
    datum.integrals.options = initSumOptions(datum.integrals.options, {
        molecules,
        nucleus,
    });
}
function addIntegral(datum, options) {
    const { from, to } = options;
    const { x, re } = datum.data;
    const shiftX = getShiftX(datum);
    const integration = xyIntegration({ x, y: re }, { from, to });
    const integral = {
        id: v4(),
        originalFrom: from - shiftX,
        originalTo: to - shiftX,
        from,
        to,
        integral: integration,
        absolute: integration,
        kind: 'signal',
    };
    datum.integrals.values.push(integral);
}
function handleAddIntegral(draft, action) {
    const { startX, endX } = action.payload;
    const { data, molecules, view: { spectra: { activeTab: nucleus }, }, } = draft;
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum?.id) {
        const [from, to] = getRange(draft, { startX, endX });
        const datum = data[activeSpectrum.index];
        addIntegral(datum, { from, to });
        initiateIntergalSumOptions(datum, { molecules, nucleus });
        updateIntegralsRelativeValues(datum);
    }
}
function handleDeleteIntegral(draft, action) {
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum) {
        const state = original(draft);
        const { index } = activeSpectrum;
        const { id: integralID } = action?.payload || {};
        const datum = draft.data[index];
        if (!integralID) {
            datum.integrals.values = [];
        }
        else {
            const peakIndex = state.data[index].integrals.values.findIndex((p) => p.id === integralID);
            datum.integrals.values.splice(peakIndex, 1);
            updateIntegralsRelativeValues(datum);
        }
    }
}
function handleChangeIntegral(draft, action) {
    const activeSpectrum = getActiveSpectrum(draft);
    const state = original(draft);
    const { integral } = action.payload;
    if (activeSpectrum?.id) {
        const { index } = activeSpectrum;
        const originalDatum = state.data[index];
        const datum = draft.data[index];
        const { x, re } = originalDatum.data;
        const integralIndex = originalDatum.integrals.values.findIndex((i) => i.id === integral.id);
        if (integralIndex !== -1) {
            datum.integrals.values[integralIndex] = {
                ...integral,
                originalFrom: integral.from,
                originalTo: integral.to,
                absolute: xyIntegration({ x, y: re }, { from: integral.from, to: integral.to }),
            };
            updateIntegralsRelativeValues(datum);
        }
    }
}
function handleChangeIntegralsRelativeValue(draft, action) {
    const activeSpectrum = getActiveSpectrum(draft);
    const { id, value } = action.payload;
    if (activeSpectrum?.id) {
        const { index } = activeSpectrum;
        changeIntegralsRelative(draft.data[index], { id, value });
    }
}
function handleChangeIntegralsSumFlag(draft) {
    const activeSpectrum = getActiveSpectrum(draft);
    if (activeSpectrum) {
        const { index } = activeSpectrum;
        const integralOptions = draft.data[index].integrals.options;
        integralOptions.isSumConstant = !integralOptions.isSumConstant;
    }
}
function handleCutIntegral(draft, action) {
    const { cutValue } = action.payload;
    const spectrum = getSpectrum(draft);
    const integrals = spectrum.integrals.values;
    for (let i = 0; i < integrals.length; i++) {
        const { to, from } = integrals[i];
        if (cutValue > from && cutValue < to) {
            integrals.splice(i, 1);
            addIntegral(spectrum, { from, to: cutValue });
            addIntegral(spectrum, { from: cutValue, to });
        }
    }
    updateIntegralsRelativeValues(spectrum);
}
function toggleIntegralsViewProperty(draft, key) {
    setIntegralsViewProperty(draft, key, (flag) => !flag);
}
//action
function handleToggleIntegralsViewProperty(draft, action) {
    const { key } = action.payload;
    toggleIntegralsViewProperty(draft, key);
}
export { handleCutIntegral, handleChangeIntegralSum, handleAddIntegral, handleDeleteIntegral, handleChangeIntegral, handleChangeIntegralsRelativeValue, handleChangeIntegralsSumFlag, handleToggleIntegralsViewProperty, };
